@@ -7,4 +7,7 @@ class ZealConfig(AppConfig):
     name = "zeal"
 
     def ready(self):
+        from .constants import initialize_app_registry
+
+        initialize_app_registry()
         patch()
